@@ -24,6 +24,7 @@
  */
 
 #include <string.h>
+#include <strings.h>
 #include <gtk/gtk.h>
 
 #include <audacious/drct.h>
@@ -34,7 +35,6 @@
 #include <libaudgui/libaudgui-gtk.h>
 
 #include "actions-equalizer.h"
-#include "config.h"
 #include "plugin.h"
 #include "skins_cfg.h"
 #include "ui_equalizer.h"
@@ -454,7 +454,7 @@ void equalizerwin_show (gboolean show)
     {
         config.equalizer_visible = show;
         button_set_active (mainwin_eq, show);
-        equalizerwin_real_show (config.player_visible && show);
+        equalizerwin_real_show (show && gtk_widget_get_visible (mainwin));
     }
 }
 
